//Blink LED in the Start Task

#include  <bsp_os.h>
#include  "bsp.h"

#include  <cpu/include/cpu.h>
#include  <common/include/common.h>
#include  <kernel/include/os.h>
#include  <kernel/include/os_trace.h>

#include  <common/include/lib_def.h>
#include  <common/include/rtos_utils.h>
#include  <common/include/toolchains.h>

/********************************************************************************************************
*                                             LOCAL DEFINES
********************************************************************************************************/
#define  START_TASK_PRIO              21u								// Start Task priority
#define  START_TASK_STK_SIZE         512u								// Start Task stack size
#define  TASK_0_STK_SIZE			256u
#define  TASK_1_STK_SIZE			256u

/********************************************************************************************************
*                                        LOCAL GLOBAL VARIABLES
********************************************************************************************************/
static  CPU_STK  StartTaskStk[START_TASK_STK_SIZE];  					// Start Task Stack.
static  OS_TCB   StartTaskTCB;											// Start Task TCB.
static  CPU_STK  Task0Stk[TASK_0_STK_SIZE];
static  OS_TCB	 Task0TCB;
static  CPU_STK  Task1Stk[TASK_1_STK_SIZE];
static  OS_TCB	 Task1TCB;

/*********************************************************************************************************
*                                       LOCAL FUNCTION PROTOTYPES
*********************************************************************************************************/
static void StartTask(void *p_arg);										// Start Task prototype
static void Task0(void *p_arg);
static void Task1(void *p_arg);

int main (void)
{
    RTOS_ERR  err;

    BSP_SystemInit();                                           		// Initialize System.
    CPU_Init();                                                 		// Initialize CPU.

    OS_TRACE_INIT();
    OSInit(&err);                                               		// Initialize the Kernel.
    APP_RTOS_ASSERT_DBG((RTOS_ERR_CODE_GET(err) == RTOS_ERR_NONE), 1);	//   Check error code.

    OSTaskCreate(&StartTaskTCB,                          				// Create the Start Task.
                 "Start Task",
                  StartTask,
                  DEF_NULL,
                  START_TASK_PRIO,
                 &StartTaskStk[0],
                 (START_TASK_STK_SIZE / 10u),
                  START_TASK_STK_SIZE,
                  0u,
                  0u,
                  DEF_NULL,
                 (OS_OPT_TASK_STK_CLR),
                 &err);
    APP_RTOS_ASSERT_DBG((RTOS_ERR_CODE_GET(err) == RTOS_ERR_NONE), 1);	//   Check error code.

    OSStart(&err);                                              		// Start the kernel.
    APP_RTOS_ASSERT_DBG((RTOS_ERR_CODE_GET(err) == RTOS_ERR_NONE), 1);	//   Check error code.

    return (1);
}

static void StartTask (void *p_arg)
{
    RTOS_ERR  err;
    PP_UNUSED_PARAM(p_arg);                                     		// Prevent compiler warning.
    BSP_TickInit();                                             		// Initialize Kernel tick source.

#if (OS_CFG_STAT_TASK_EN == DEF_ENABLED)
    OSStatTaskCPUUsageInit(&err);                               		// Initialize CPU Usage.
    APP_RTOS_ASSERT_DBG((RTOS_ERR_CODE_GET(err) == RTOS_ERR_NONE), ;);	//   Check error code.
#endif

#ifdef CPU_CFG_INT_DIS_MEAS_EN
    CPU_IntDisMeasMaxCurReset();                                		// Initialize interrupts disabled measurement.
#endif

    Common_Init(&err);                                          		// Call common module initialization example.
    APP_RTOS_ASSERT_CRITICAL(err.Code == RTOS_ERR_NONE, ;);

    BSP_OS_Init();                                              		// Initialize the BSP. It is expected that the BSP ...
                                                                		// ... will register all the hardware controller to ...
                                                                		// ... the platform manager at this moment.
    OSTaskCreate(&Task0TCB,                    							// Create custom task
                 "Task_0",
                 Task0,
                 0u,
				 START_TASK_PRIO+1,
                 &Task0Stk[0u],
                 Task0Stk[TASK_0_STK_SIZE / 10u],
                 TASK_0_STK_SIZE,
                 0u,
                 0u,
                 0u,
                 (OS_OPT_TASK_STK_CHK | OS_OPT_TASK_STK_CLR),
				 &err);

    OSTaskCreate(&Task1TCB,                    							// Create custom task
                 "Task_1",
                 Task1,
                 0u,
				 START_TASK_PRIO+1,
                 &Task1Stk[0u],
                 Task1Stk[TASK_1_STK_SIZE / 10u],
                 TASK_1_STK_SIZE,
                 0u,
                 0u,
                 0u,
                 (OS_OPT_TASK_STK_CHK | OS_OPT_TASK_STK_CLR),
				 &err);

    while (1)
    {
    	OSTimeDlyHMSM(1u, 0u, 0u, 0u, OS_OPT_TIME_HMSM_STRICT, &err);
        APP_RTOS_ASSERT_DBG((RTOS_ERR_CODE_GET(err) == RTOS_ERR_NONE), ;); //   Check error code.
    }
}

static void Task0 (void *p_arg)
{
    RTOS_ERR err;
    PP_UNUSED_PARAM(p_arg);                                     		  // Prevent compiler warning

    while (1)
    {
    	BSP_LedToggle(0);
       	OSTimeDlyHMSM(0u, 0u, 1u, 0u, OS_OPT_TIME_HMSM_STRICT, &err);
    }
}

static void Task1 (void *p_arg)
{
    RTOS_ERR err;
    PP_UNUSED_PARAM(p_arg);                                     		// Prevent compiler warning

    while(DEF_TRUE)
    {
    	BSP_LedToggle(1);
       	OSTimeDlyHMSM(0u, 0u, 1u, 200u, OS_OPT_TIME_HMSM_STRICT, &err);
    }
}

